#[repr(transparent)]pub struct JoinRule {
inner: TypedObjectRef<JoinRule, ()>,
phantom: PhantomData<()>,
}Expand description
The join rule of a room.
GLib type: GObject with reference counted clone semantics.
Fields
inner: TypedObjectRef<JoinRule, ()>phantom: PhantomData<()>Implementations
Sourceimpl JoinRule
impl JoinRule
Sourcepub fn display_name(&self) -> <RefCell<String> as Property>::Value
pub fn display_name(&self) -> <RefCell<String> as Property>::Value
The string to use to display this join rule.
This string can contain markup.
Sourcepub fn membership_room(&self) -> <BoundObject<PillSource> as Property>::Value
pub fn membership_room(&self) -> <BoundObject<PillSource> as Property>::Value
The room we need to be a member of to match this join rule, if any.
This can be a Room or a RemoteRoom.
Sourcepub fn we_can_join(&self) -> <Cell<bool> as Property>::Value
pub fn we_can_join(&self) -> <Cell<bool> as Property>::Value
Whether our own user can join this room on their own.
Sourcepub fn anyone_can_join(&self) -> <Cell<bool> as Property>::Value
pub fn anyone_can_join(&self) -> <Cell<bool> as Property>::Value
Whether anyone can join this room on their own.
Sourcepub fn connect_room_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_room_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the room property
Sourcepub fn connect_value_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_value_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the value property
Sourcepub fn connect_can_knock_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_can_knock_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the can-knock property
Sourcepub fn connect_display_name_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_display_name_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the display-name property
Sourcepub fn connect_membership_room_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_membership_room_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the membership-room property
Sourcepub fn connect_we_can_join_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_we_can_join_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the we-can-join property
Sourcepub fn connect_anyone_can_join_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_anyone_can_join_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the anyone-can-join property
Sourcepub fn notify_room(&self)
pub fn notify_room(&self)
Notify listeners of a change in the room property
Sourcepub fn notify_value(&self)
pub fn notify_value(&self)
Notify listeners of a change in the value property
Sourcepub fn notify_can_knock(&self)
pub fn notify_can_knock(&self)
Notify listeners of a change in the can-knock property
Sourcepub fn notify_display_name(&self)
pub fn notify_display_name(&self)
Notify listeners of a change in the display-name property
Sourcepub fn notify_membership_room(&self)
pub fn notify_membership_room(&self)
Notify listeners of a change in the membership-room property
Sourcepub fn notify_we_can_join(&self)
pub fn notify_we_can_join(&self)
Notify listeners of a change in the we-can-join property
Sourcepub fn notify_anyone_can_join(&self)
pub fn notify_anyone_can_join(&self)
Notify listeners of a change in the anyone-can-join property
Sourceimpl JoinRule
impl JoinRule
pub fn new() -> Self
Sourcepub(super) fn init(&self, room: &Room)
pub(super) fn init(&self, room: &Room)
Initialize the join rule with the room where it applies.
Sourcepub(super) fn update(&self, join_rule: Option<&MatrixJoinRule>)
pub(super) fn update(&self, join_rule: Option<&MatrixJoinRule>)
Update the join rule with the given value from the SDK.
Sourcepub(crate) fn matrix_join_rule(&self) -> Option<MatrixJoinRule>
pub(crate) fn matrix_join_rule(&self) -> Option<MatrixJoinRule>
Get the current join rule from the SDK.
Sourcepub(crate) async fn set_matrix_join_rule(
&self,
rule: MatrixJoinRule,
) -> Result<(), ()>
pub(crate) async fn set_matrix_join_rule( &self, rule: MatrixJoinRule, ) -> Result<(), ()>
Change the join rule.
Sourcepub(crate) fn connect_changed<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub(crate) fn connect_changed<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Connect to the signal emitted when the join rule changed.